fireworks.utilities.tests package — FireWorks 1.4.4 documentation

# fireworks.utilities.tests package

## Submodules

## fireworks.utilities.tests.test_filepad module

class `fireworks.utilities.tests.test_filepad.` `FilePadTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  `tearDown`()
  `test_add_file`()
  `test_add_file_with_no_identifier`()
  `test_delete_file`()
  `test_get_file`()
  `test_update_file`()
  `test_update_file_by_id`()

## fireworks.utilities.tests.test_fw_serializers module

class `fireworks.utilities.tests.test_fw_serializers.` `ExplicitSerializationTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  `test_explicit_serialization`()

class `fireworks.utilities.tests.test_fw_serializers.` `ExplicitTestSerializer`(a)

  Bases: `fireworks.utilities.fw_serializers.FWSerializable`

  classmethod `from_dict`(m_dict)
  `to_dict`()

class `fireworks.utilities.tests.test_fw_serializers.` `SerializationTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  `tearDown`()
  `test_as_dict`()
  `test_complex_json`()
  `test_complex_yaml`()
  `test_implicit_serialization`()
  `test_json`()
  `test_numpy_array`()
  `test_sanity`()
  `test_serialize_fw_decorator`()
  `test_unicode_json`()
  `test_unicode_json_file`()
  `test_unicode_yaml`()
  `test_unicode_yaml_file`()
  `test_yaml`()

## fireworks.utilities.tests.test_update_collection module

class `fireworks.utilities.tests.test_update_collection.` `UpdateCollectionTests`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  classmethod `setUpClass`()
  classmethod `tearDownClass`()
  `test_update_path`()

## Module contents